******************************
The sherpa.plot.testing module
******************************

.. currentmodule:: sherpa.plot.testing

.. automodule:: sherpa.plot.testing

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      check_empty
      check_full